# remirepo spec file for php-pecl-vips
#
# Copyright (c) 2016-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-vips}

%bcond_without      tests

%global pecl_name   vips
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
#global prever      RC9
%global sources     %{pecl_name}-%{version}%{?prever}
%global _configure  ../%{sources}/configure

# Ensure runtime version > buildtime version, for possible new symbols
%global vipsbuildver %(pkg-config --silence-errors --modversion vips 2>/dev/null || echo 65536)

Summary:        PHP extension for interfacing with libvips
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.0.13
Release:        3%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP-3.01
Group:          Development/Languages
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
# ensure latest version is used (upstream requires 8.2)
BuildRequires:  pkgconfig(vips) >= 8.14
Requires:       vips%{?_isa} >= %{vipsbuildver}

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This extension uses libvips to provide image processing facilities.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't register test files on install
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/define PHP_VIPS_VERSION/{s/.* "//;s/".*$//;p}' php_vips.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-vips \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-vips \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Test & Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE.txt}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Jul 21 2023 Remi Collet <remi@remirepo.net> - 1.0.13-3
- build out of sources tree

* Mon Jan  2 2023 Remi Collet <remi@remirepo.net> - 1.0.13-2
- rebuild against vips 8.14

* Wed Feb 16 2022 Remi Collet <remi@remirepo.net> - 1.0.13-1
- update to 1.0.13

* Wed Sep  8 2021 Remi Collet <remi@remirepo.net> - 1.0.12-6
- test build for upstream patch

* Mon Sep  6 2021 Remi Collet <remi@remirepo.net> - 1.0.12-5
- rebuild with workaround for https://github.com/libvips/php-vips-ext/issues/43

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.0.12-3
- rebuild for PHP 8.0.0RC1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.0.12-2
- rebuild for PHP 8.0.0beta3

* Sun Aug 30 2020 Remi Collet <remi@remirepo.net> - 1.0.12-1
- update to 1.0.12

* Fri Aug 28 2020 Remi Collet <remi@remirepo.net> - 1.0.11-1
- update to 1.0.11

* Wed Jan  8 2020 Remi Collet <remi@remirepo.net> - 1.0.10-2
- rebuild with libvips 8.9.0

* Thu Sep 26 2019 Remi Collet <remi@remirepo.net> - 1.0.10-1
- update to 1.0.10

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.0.9-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.0.9-2
- rebuild for 7.4.0beta1

* Fri Oct  5 2018 Remi Collet <remi@remirepo.net> - 1.0.9-1
- update to 1.0.9

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.0.8-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.0.8-2
- rebuild for 7.3.0alpha4 new ABI

* Thu Nov 23 2017 Remi Collet <remi@remirepo.net> - 1.0.8-1
- Update to 1.0.8

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.0.7-3
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 1.0.7-2
- rebuild for 7.2.0alpha2

* Tue Jun  6 2017 Remi Collet <remi@remirepo.net> - 1.0.7-1
- Update to 1.0.7

* Fri Apr 21 2017 Remi Collet <remi@remirepo.net> - 1.0.6-1
- Update to 1.0.6

* Mon Apr 10 2017 Remi Collet <remi@remirepo.net> - 1.0.5-2
- rebuild with libvips 8.5.2

* Sun Apr  9 2017 Remi Collet <remi@remirepo.net> - 1.0.5-1
- Update to 1.0.5

* Fri Dec 30 2016 Remi Collet <remi@fedoraproject.org> - 1.0.4-1
- Update to 1.0.4

* Thu Dec 29 2016 Remi Collet <remi@fedoraproject.org> - 1.0.3-1
- Update to 1.0.3 (broken)
  open https://github.com/jcupitt/php-vips/issues/27

* Tue Dec 06 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.0.1-2
- rebuild with PHP 7.1.0 GA

* Fri Nov 25 2016 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1

* Thu Nov 24 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- initial package, version 1.0.0 (php 7, stable)

